pub trait Renderer {
Show 15 methods
// Required methods
fn start_layer(&mut self, bounds: Rectangle);
fn end_layer(&mut self);
fn start_transformation(&mut self, transformation: Transformation);
fn end_transformation(&mut self);
fn fill_quad(&mut self, quad: Quad, background: impl Into<Background>);
fn allocate_image(
&mut self,
handle: &Handle,
callback: impl FnOnce(Result<Allocation, Error>) + Send + 'static,
);
fn hint(&mut self, scale: Scale);
fn scale(&self) -> Option<Scale>;
fn reset(&mut self, new_bounds: Rectangle);
fn settings(&self) -> Settings;
// Provided methods
fn with_layer(&mut self, bounds: Rectangle, f: impl FnOnce(&mut Self)) { ... }
fn with_transformation(
&mut self,
transformation: Transformation,
f: impl FnOnce(&mut Self),
) { ... }
fn with_translation(
&mut self,
translation: Vector,
f: impl FnOnce(&mut Self),
) { ... }
fn hint_factor(&self) -> Option<f32> { ... }
fn tick(&mut self) { ... }
}Expand description
A component that can be used by widgets to draw themselves on a screen.
Required Methods
Sourcefn start_layer(&mut self, bounds: Rectangle)
fn start_layer(&mut self, bounds: Rectangle)
Starts recording a new layer.
Sourcefn end_layer(&mut self)
fn end_layer(&mut self)
Ends recording a new layer.
The new layer will clip its contents to the provided bounds.
Sourcefn start_transformation(&mut self, transformation: Transformation)
fn start_transformation(&mut self, transformation: Transformation)
Starts recording with a new Transformation.
Sourcefn end_transformation(&mut self)
fn end_transformation(&mut self)
Ends recording a new layer.
The new layer will clip its contents to the provided bounds.
Sourcefn fill_quad(&mut self, quad: Quad, background: impl Into<Background>)
fn fill_quad(&mut self, quad: Quad, background: impl Into<Background>)
Fills a Quad with the provided Background.
Sourcefn allocate_image(
&mut self,
handle: &Handle,
callback: impl FnOnce(Result<Allocation, Error>) + Send + 'static,
)
fn allocate_image( &mut self, handle: &Handle, callback: impl FnOnce(Result<Allocation, Error>) + Send + 'static, )
Creates an image::Allocation for the given image::Handle and calls the given callback with it.
Sourcefn hint(&mut self, scale: Scale)
fn hint(&mut self, scale: Scale)
Provides hints to the Renderer about the rendering target.
This may be used internally by the Renderer to perform optimizations
and/or improve rendering quality.
For instance, providing a Scale may be used by some renderers to
perform metrics hinting internally in physical coordinates while keeping
layout coordinates logical and, therefore, maintain linearity.
Provided Methods
Sourcefn with_layer(&mut self, bounds: Rectangle, f: impl FnOnce(&mut Self))
fn with_layer(&mut self, bounds: Rectangle, f: impl FnOnce(&mut Self))
Draws the primitives recorded in the given closure in a new layer.
The layer will clip its contents to the provided bounds.
Sourcefn with_transformation(
&mut self,
transformation: Transformation,
f: impl FnOnce(&mut Self),
)
fn with_transformation( &mut self, transformation: Transformation, f: impl FnOnce(&mut Self), )
Applies a Transformation to the primitives recorded in the given closure.
Sourcefn with_translation(&mut self, translation: Vector, f: impl FnOnce(&mut Self))
fn with_translation(&mut self, translation: Vector, f: impl FnOnce(&mut Self))
Applies a translation to the primitives recorded in the given closure.
Sourcefn hint_factor(&self) -> Option<f32>
fn hint_factor(&self) -> Option<f32>
Returns the last hint factor provided as a hint,
only if Settings::metrics_hinting is enabled.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.